@@ -9,11 +9,17 @@ import os
 import sys
 
 from QuickProject import QproDefaultStatus as qs_default_status
-from QuickProject import external_exec, _ask
+from QuickProject import external_exec, user_pip
 
-from .NetTools import headers
 from .__cache__ import QsCache
-from .__config__ import QsConfig, dir_char, platform, qs_default_console
+from .__config__ import (
+    QsConfig,
+    dir_char,
+    platform,
+    qs_default_console,
+    _ask,
+    user_lang,
+)
 
 name = "QuickStart_Rhy"
 
@@ -21,12 +27,10 @@ user_root = os.path.expanduser("~")
 qs_config = QsConfig(os.path.join(user_root, ".qsrc"))
 qs_cache = QsCache(os.path.join(user_root, ".qs_cache"))
 
-user_lang = qs_config.basicSelect("default_language")
 user_currency = qs_config.basicSelect("default_currency")
 trans_engine = qs_config.basicSelect("default_translate_engine")["support"][
     qs_config.basicSelect("default_translate_engine")["index"]
 ]
-user_pip = qs_config.basicSelect("default_pip")
 force_show_img = qs_config.basicSelect("force_show_img")
 
 qs_error_string = f'[bold red][{"ERROR" if user_lang != "zh" else "错误"}]'
@@ -44,14 +48,14 @@ def requirePackage(
     set_pip: str = user_pip,
 ):
     """
-    获取本机上的python第三方库，如没有则询问安装
+    获取本机上的python第三方库
 
-    :param not_ask: 不询问，无依赖项则报错
-    :param set_pip: 设置pip路径
     :param pname: 库名
     :param module: 待引入的模块名，可缺省
     :param real_name: 用于 pip3 install 的名字
     :param not_exit: 安装后不退出
+    :param not_ask: 不询问
+    :param set_pip: pip3的路径
     :return: 库或模块的地址
     """
     try:
@@ -62,12 +66,17 @@ def requirePackage(
         if _ask(
             {
                 "type": "confirm",
-                "message": f"""Qs require {pname + (' -> ' + module if module else '')}, confirm to install?  
-  Qs 依赖 {pname + (' -> ' + module if module else '')}, 确认安装?""",
+                "message": f"""Qs require {pname + (' -> ' + module if module else '')}, confirm to install?"""
+                if user_lang != "zh"
+                else f"""Qs 依赖 {pname + (' -> ' + module if module else '')}，确认安装吗？""",
                 "default": True,
             }
         ):
-            with qs_default_status("Installing..." if user_lang != "zh" else "正在安装..."):
+            with qs_default_status(
+                f"Installing {pname if not real_name else real_name}"
+                if user_lang != "zh"
+                else f"正在安装 {pname if not real_name else real_name}"
+            ):
                 st, _ = external_exec(
                     f"{set_pip} install {pname if not real_name else real_name} -U",
                     True,
@@ -75,20 +84,26 @@ def requirePackage(
             if st:
                 qs_default_console.print(
                     qs_error_string,
-                    f"Install {pname + (' -> ' + module if module else '')} failed, please install it manually!",
+                    f"Install {pname + (' -> ' + module if module else '')} failed, please install it manually: "
+                    if user_lang != "zh"
+                    else f"安装 {pname + (' -> ' + module if module else '')} 失败，请手动安装: ",
+                    f"'{set_pip} install {pname if not real_name else real_name} -U'",
                 )
                 exit(-1)
             if not_exit:
                 exec(f"from {pname} import {module}" if module else f"import {pname}")
             else:
                 qs_default_console.print(
-                    qs_info_string, f'just run again: "{" ".join(sys.argv)}"'
+                    qs_info_string,
+                    "Install complete! Run again:"
+                    if user_lang != "zh"
+                    else f"安装完成！再次运行:",
+                    " ".join(sys.argv),
                 )
                 exit(0)
         else:
             exit(-1)
-    finally:
-        return eval(f"{module if module else pname}")
+    return eval(f"{module if module else pname}")
 
 
 def cut_string(string: str, length: int) -> list:
@@ -99,15 +114,16 @@ def cut_string(string: str, length: int) -> list:
     :param length: 切分长度
     :return: 切分后产生的list
     """
-    string = string.strip().replace("\n", " ")
+    string = string.strip()
     res, cur, cnt = [], "", 0
     for i in string:
-        cnt += 2 if ord(i) > 255 else 1
+        _char_len = 2 if ord(i) > 255 else 1 if ord(i) > 127 else 1.5
+        cnt += _char_len
         if cnt <= length:
             cur += i
         else:
             res.append(cur)
-            cur, cnt = i, 2 if ord(i) > 255 else 1
+            cur, cnt = i, _char_len
     if cur:
         res.append(cur)
     return res
@@ -468,7 +484,8 @@ def sas():
             question["default"] = uids[max(_default, key=_default.get)]
     else:
         default = {}
-    select = _ask(question)
+    if not (select := _ask(question)):
+        return
     uid = devices[select]["uid"]
     default[uid] = default.get(uid, 0) + 1
 
